# 使用注意事项

## 个人主页效果

如果你对个人主页效果有疑问，或者想了解更多的个人主页效果，请到这个库[JXPagingView 点击参看](https://github.com/pujiaxin33/JXPagingView)

## 侧滑手势处理

[侧滑手势处理文档地址](https://github.com/pujiaxin33/JXCategoryView/blob/master/Document/%E4%BE%A7%E6%BB%91%E6%89%8B%E5%8A%BF%E5%A4%84%E7%90%86.md)

## 左滑删除

因为列表容器可以左右滑动，如果要开启左滑删除，这个时候系统会响应列表容器的左右滑动，而不是列表cell的左滑删除。所以，建议的方案是禁止列表容器滑动，这样就可以响应列表的左滑删除了。
列表容器滑动禁止，使用下面的代码：
```Objective-C
self.listContainerView.scrollView.scrollEnabled = NO;
```

## `FDFullscreenPopGesture`等全屏手势处理

[`FDFullscreenPopGesture`等全屏手势处理文档地址](https://github.com/pujiaxin33/JXCategoryView/blob/master/Document/%E5%85%A8%E5%B1%8F%E6%89%8B%E5%8A%BF%E5%A4%84%E7%90%86.md)

## JXCategoryView状态刷新

初始化过后，有新的数据源、属性配置有变动时（比如从服务器拉取回来数据，重新赋值titles），需要调用`reloadData`方法刷新状态。

## defaultSelectedIndex使用

用于配置默认展示列表的index，比如默认想要展示第三个列表，在初始化的时候添加下面代码：
```Objective-C
self.categoryView.defaultSelectedIndex = 2;
self.listContainerView.defaultSelectedIndex = 2;
```

## contentScrollView关联说明

JXCategoryView没有与contentScrollView强关联，你甚至可以不设置这个属性，把它当做简单的SegmentedControl。他们之间布局没有任何要求，可以把JXCategoryView放入导航栏、UITableViewSectionHeader等任何你想要的地方。

## 点击Item之后contentScrollView切换效果

系统内部通过代码`[self.contentScrollView setContentOffset:CGPointMake(targetIndex*self.contentScrollView.bounds.size.width, 0) animated:self.isContentScrollViewClickTransitionAnimationEnabled];`实现切换。

设置`contentScrollViewClickTransitionAnimationEnabled`属性即可控制是否`animated`

## 列表cell点击跳转示例

Demo的使用方法是给列表新增一个属性：`@property (nonatomic, strong) UINavigationController *naviController`，然后将父VC的navigationController赋值给它。这样列表的cell点击就可以通过自定义的`naviController`属性进行跳转了。详情参考源码[LoadDataListBaseViewController](https://github.com/pujiaxin33/JXCategoryView/blob/master/JXCategoryView/Example/LoadData/LoadDataListBaseViewController.h)

## 列表调用`presentViewController`方法

参考上面【列表cell点击跳转示例】示例，传递`UINavigationController`给列表的`naviController`属性，然后用`naviController`调用`presentViewController`。不能直接用列表来`presentViewController`

## 代码选中指定index

当业务需要某个时刻要跳转到指定index，比如当前index=0，用户点击了某个按钮，需要立即跳转到index=3的位置，使用下列代码即可：
```Objective-c
    [self.categoryView selectItemAtIndex:3];
    [self.listContainerView didClickSelectedItemAtIndex:3];
```

## JXCategoryView.collectionView高度取整说明

高度取整代码：
```Objective-c
- (void)layoutSubviews {
    [super layoutSubviews];

    self.collectionView.frame = CGRectMake(0, 0, self.bounds.size.width, floor(self.bounds.size.height));
}
```
部分使用者为了适配不同的手机屏幕尺寸，JXCategoryView的宽高比要求保持一样。所以它的高度就会因为不同宽度的屏幕而不一样。计算出来的高度，有时候会是位数很长的浮点数，如果把这个高度设置给UICollectionView就会触发内部的一个错误。所以，为了规避这个问题，在这里对高度统一向下取整。
如果向下取整导致了你的页面异常，请自己重新设置JXCategoryView的高度，保证为整数即可。

## 对父VC的automaticallyAdjustsScrollViewInsets属性设置为NO

因为JXCategoryView内部使用了UICollectionView，在某些系统会对内部的UICollectionView进行错误的调整。所以，内部会自己找到父VC，然后将其automaticallyAdjustsScrollViewInsets属性设置为NO。
```Objective-c
- (void)willMoveToSuperview:(UIView *)newSuperview {
    [super willMoveToSuperview:newSuperview];

    UIResponder *next = newSuperview;
    while (next != nil) {
        if ([next isKindOfClass:[UIViewController class]]) {
            ((UIViewController *)next).automaticallyAdjustsScrollViewInsets = NO;
            break;
        }
        next = next.nextResponder;
    }
}
```

## 使用多行文本

通过设置`JXCategoryTitleView`的`titleNumberOfLines`属性为指定行数，比如2就是显示两行。但是因为内部实现原理限制，目前暂不支持自动换行，需要自己插入\n换行符。详情请参考【多行文本】使用示例。

## iPhoneX刘海屏手机列表底部安全距离显示建议

1、使用`JXCategoryListCollectionContainerView`类不会有底部安全边距问题；
2、列表使用`UIView`封装不会有底部安全边距问题；
3、列表使用`UIViewController`封装有底部安全边距问题，添加代码` [self addChildViewController:listVC];`即可避免，完整代码如下：
```Objective-C
- (id<JXCategoryListContentViewDelegate>)listContainerView:(JXCategoryListContainerView *)listContainerView initListForIndex:(NSInteger)index {
    LoadDataListContainerListViewController *listVC = [[LoadDataListContainerListViewController alloc] init];
    listVC.naviController = self.navigationController;
    //如果列表是UIViewController包裹的，需要添加addChildViewController代码，这样子在iPhoneX系列手机就不会有底部安全距离错误的问题！！！
    [self addChildViewController:listVC];
    return listVC;
}
```

## 列表容器禁止左右滑动

添加如下代码即可：
```Objective-C
self.listContainerView.scrollView.scrollEnabled = NO;
```
 
## 单个cell刷新 

调用`- (void)reloadCellAtIndex:(NSInteger)index;`方法刷新指定index。
某些情况需要刷新某一个cell的UI显示，比如红点示例里面。

## 点击item时指示器和列表滚动时效果一致

目前指示器的过渡效果分为：跟随列表滚动、点击item过渡两种。它们分开处理，如果你希望点击item时和跟随列表滚动效果一致，请参考如下代码：
```Objective-C
indicatorLineView.scrollStyle = JXCategoryIndicatorScrollStyleSameAsUserScroll;
```
目前仅支持`JXCategoryIndicatorLineView`、`JXCategoryIndicatorDotLineView`类。如果是自定义的指示器请参考它们的处理方式支持该效果，其实就是通过动画的方式模拟跟随列表滚动的效果。
 
## 自定义建议

`JXCategoryView`即使提供了灵活扩展，也不可能满足所有情况。未能满足特殊需求的情况，建议通过fork仓库，实现特殊效果。
